@@ -207,7 +207,7 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
   MagickBooleanType
     fire,
     pend,
-    respect_parenthesis;
+    respect_parentheses;
 
   MagickStatusType
     status;
@@ -254,7 +254,7 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
   NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
-  respect_parenthesis=MagickFalse;
+  respect_parentheses=MagickFalse;
   status=MagickTrue;
   /*
     Identify an image.
@@ -807,9 +807,10 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
       {
         if (LocaleCompare("regard-warnings",option+1) == 0)
           break;
-        if (LocaleNCompare("respect-parentheses",option+1,17) == 0)
+        if ((LocaleNCompare("respect-parentheses",option+1,17) == 0) ||
+            (LocaleNCompare("respect-parenthesis",option+1,17) == 0))
           {
-            respect_parenthesis=(*option == '-') ? MagickTrue : MagickFalse;
+            respect_parentheses=(*option == '-') ? MagickTrue : MagickFalse;
             break;
           }
         ThrowIdentifyException(OptionError,"UnrecognizedOption",option)
